from emod_api import schema_to_class as s2c
from emod_api.interventions import utils
import json

iv_name = "ART"

def new_intervention( camp ):
    """
    AntiRetroviralTherapy intervention wrapper. Just the intervention. No configuration yet.
    """
    schema_path = camp.schema_path
    # First, get the objects
    intervention = s2c.get_class_with_defaults( "AntiretroviralTherapy", schema_path )
    return intervention

def new_intervention_event( 
        camp, 
        start_day=1, 
        coverage=1.0, 
        node_ids=None
    ):
    """
    ART intervention as complete (scheduled) event.
    """
    art_iv = new_intervention( camp )

    # Coordinator
    coordinator = s2c.get_class_with_defaults( "StandardEventCoordinator", camp.schema_path )
    coordinator.Intervention_Config = art_iv
    coordinator.Demographic_Coverage = coverage

    # Event
    event = s2c.get_class_with_defaults( "CampaignEvent", camp.schema_path ) 
    event.Event_Coordinator_Config = coordinator
    event.Start_Day = float(start_day)
    event.Nodeset_Config = utils.do_nodes( camp.schema_path, node_ids )
    event.Event_Coordinator_Config.pop( "Targeting_Config" )

    return event

def new_intervention_as_file( camp, start_day, filename=None ):
    campaign = {}
    campaign["Events"] = []
    campaign["Events"].append( new_intervention_event( camp, start_day ) )
    if filename is None:
        filename = "AntiRetroviralTherapy.json"
    with open( filename, "w" ) as camp_file:
        json.dump( campaign, camp_file, sort_keys=True, indent=4 )
    return filename

