#!/usr/bin/env python
import unittest
import sys
from pathlib import Path

import emod_api.campaign as camp
import emodpy_hiv.interventions.outbreak as ob
import emodpy_hiv.interventions.art as art

parent = Path(__file__).resolve().parent
sys.path.append(str(parent))
import schema_path_file


class HIVInterventionTest(unittest.TestCase):
    schema_path = schema_path_file.schema_path

    # region unittest setup and teardown method
    @classmethod
    def setUpClass(cls):
        camp.schema_path = cls.schema_path

    def setUp(self):
        print(f"running {self._testMethodName}:")
        pass

    def tearDown(self):
        print("end of test\n")
        pass
    # endregion

    # region outbreak
    def test_outbreak_new_intervention(self):
        timestep = 365
        coverage = 0.05
        event = ob.new_intervention(timestep=timestep, camp=camp, coverage=coverage)
        self.assertEqual(event.Start_Day, timestep)
        self.assertEqual(event.Event_Coordinator_Config.Intervention_Config['class'], 'OutbreakIndividual')
        self.assertEqual(event.Event_Coordinator_Config.Demographic_Coverage, coverage)
    # endregion

    # region ART
    def test_art_new_default(self):
        start_day = 1
        coverage = 1.0
        node_ids = []
        event = art.new_intervention_event(camp=camp, start_day=start_day, coverage=coverage, node_ids=None)
        print(event)

        self.assertEqual(event.Start_Day, start_day)
        self.assertEqual(event.Event_Coordinator_Config.Intervention_Config['class'], 'AntiretroviralTherapy')
        self.assertEqual(event.Event_Coordinator_Config.Demographic_Coverage, coverage)

    def test_art_new_custom(self):
        start_day = 5
        coverage = 0.5
        event = art.new_intervention_event(camp=camp, start_day=start_day, coverage=coverage, node_ids=None)

        self.assertEqual(event.Start_Day, start_day)
        self.assertEqual(event.Event_Coordinator_Config.Intervention_Config['class'], 'AntiretroviralTherapy')
        self.assertEqual(event.Event_Coordinator_Config.Demographic_Coverage, coverage)

if __name__ == '__main__':
    unittest.main()
